Generates univariate synthetic data using bagging. It uses
randomForest function from the randomForest package with
number of sampled predictors equal to number of all predictors.
syn.bag(y, x, xp, smoothing, proper = FALSE, ntree = 10, ...)an original data vector of length n.
a matrix (n x p) of original covariates.
a matrix (k x p) of synthesised covariates.
smoothing method for continuous variables.
...
number of trees to grow.
additional parameters passed to
randomForest.
A vector of length k with synthetic values of y.
...
...