Generates synthetic event indicator and time to event data using classification and regression trees (without or with bootstrap).
syn.survctree(y, yevent, x, xp, proper = FALSE, minbucket = 5, ...)a vector of length n with original time data.
a vector of length n with original event indicator data.
a matrix (n x p) of original covariates.
a matrix (k x p) of synthesised covariates.
for proper synthesis (proper = TRUE) a CART
model is fitted to a bootstrapped sample of the original data.
the minimum number of observations in
any terminal node. See ctree_control
for details.
additional parameters passed to ctree.
A list with the following components:
a vector of length k with synthetic time values.
a vector of length k with synthetic event indicator values.
The procedure for synthesis by a CART model is as follows:
For each xp find the terminal node.
Randomly
draw a donor from the members of the node and take the observed
value of yevent and y from that draw as the
synthetic values.